def add(a, b):
    return a + b


def subtract(a, b):
    return a - b


def multiply(a, b):
    return a * b


def divide(a, b):
    return a / b


def greet(name):
    return "Hello, " + name


def square(a):
    return a * a


from .calculatorbasic import add
from .calculatorbasic import subtract
from .calculatorbasic import multiply
from .calculatorbasic import divide
from .calculatorbasic import greet
from .calculatorbasic import square


from setuptools import setup

setup(name='subbutest_library', # package name
      version='1.0',               # version number
      author="Subramanya Rekhandar",  # author
      description="A test library for Basic Calculator ", 
      packages=['subbutest-library'], # packge directory
      author_email='aicareerof@gmail.com',
      zip_safe=False)